@@ -37,7 +37,7 @@
 #' #set path to EBV netCDF
 #' file <- system.file(file.path("extdata","martins_comcom_id1_20220208_v1.nc"), package="ebvcube")
 #' #get all datacubepaths of EBV netCDF
-#' datacubes <- ebv_datacubepaths(file)
+#' datacubes <- ebv_datacubepaths(file, verbose=FALSE)
 #'
 #' #set outputpath
 #' out <- file.path(system.file(package='ebvcube'),"extdata","subset_bb.tif")
@@ -50,7 +50,7 @@
 #' cSAR.germany <- ebv_read_bb(filepath = file, datacubepath = datacubes[1,1],
 #'                              entity = 1, timestep = 1:3, bb = bb_wgs84)
 #'
-#' \donttest{
+#' \dontrun{
 #' #read bb (based on EPSG 4326) - write to GeoTiff
 #' path <- ebv_read_bb(filepath = file, datacubepath = datacubes[1,1],
 #'                     entity = 1, timestep = 1, bb = bb_wgs84,
@@ -109,7 +109,7 @@ ebv_read_bb <- function(filepath, datacubepath, entity=NULL, timestep = 1, bb,
   }
 
   #file closed?
-  ebv_i_file_opened(filepath)
+  ebv_i_file_opened(filepath, verbose)
 
   #variable check
   if (checkmate::checkCharacter(datacubepath) != TRUE){
